@@ -34,6 +34,7 @@
 #include "procdialogs.h"
 #include "memmaps.h"
 #include "openfiles.h"
+#include "procproperties.h"
 #include "load-graph.h"
 #include "disks.h"
 #include "lsof.h"
@@ -136,6 +137,13 @@ cb_show_open_files (GtkAction *action, gpointer data)
     create_openfiles_dialog (procdata);
 }
 
+void
+cb_show_process_properties (GtkAction *action, gpointer data)
+{
+    ProcData *procdata = static_cast<ProcData*>(data);
+    create_procproperties_dialog (procdata);
+}
+
 void
 cb_show_lsof(GtkAction *action, gpointer data)
 {
@@ -236,6 +244,37 @@ cb_end_process_button_pressed (GtkButton *button, gpointer data)
     kill_process_helper(static_cast<ProcData*>(data), SIGTERM);
 }
 
+void
+cb_cpu_color_changed (GSMColorButton *cp, gpointer data)
+{
+    guint cpu_i = GPOINTER_TO_UINT (data);
+    GSettings *settings = g_settings_new (GSM_GSETTINGS_SCHEMA);
+
+    /* Get current values */
+    GVariant *cpu_colors_var = g_settings_get_value(settings, "cpu-colors");
+    gsize children_n = g_variant_n_children(cpu_colors_var);
+
+    /* Create builder to contruct new setting with updated value for cpu i */
+    GVariantBuilder builder;
+    g_variant_builder_init(&builder, G_VARIANT_TYPE_ARRAY);
+
+    for (guint i = 0; i < children_n; i++) {
+        if(cpu_i == i) {
+            gchar color[24];
+            GdkColor button_color;
+            gsm_color_button_get_color(cp, &button_color);
+            g_snprintf(color, sizeof(color), "#%04x%04x%04x",
+                       button_color.red, button_color.green, button_color.blue);
+            g_variant_builder_add(&builder, "(us)", i, color);
+        } else {
+            g_variant_builder_add_value(&builder,
+                                        g_variant_get_child_value(cpu_colors_var, i));
+        }
+    }
+
+    /* Just set the value and let the changed::cpu-colors signal callback do the rest. */
+    g_settings_set_value(settings, "cpu-colors", g_variant_builder_end(&builder));
+}
 
 static void change_settings_color(GSettings *settings, const char *key,
                                   GSMColorButton *cp)
@@ -248,18 +287,6 @@ static void change_settings_color(GSettings *settings, const char *key,
     g_settings_set_string (settings, key, color);
 }
 
-void
-cb_cpu_color_changed (GSMColorButton *cp, gpointer data)
-{
-    char key[80];
-    gint i = GPOINTER_TO_INT (data);
-    GSettings *settings = g_settings_new (GSM_GSETTINGS_SCHEMA);
-
-    g_snprintf(key, sizeof key, "cpu-color%d", i%4);
-
-    change_settings_color(settings, key, cp);
-}
-
 void
 cb_mem_color_changed (GSMColorButton *cp, gpointer data)
 {
@@ -328,8 +355,10 @@ cb_row_selected (GtkTreeSelection *selection, gpointer data)
             value = VERY_LOW_PRIORITY;
 
         GtkRadioAction* normal = GTK_RADIO_ACTION(gtk_action_group_get_action(procdata->action_group, "Normal"));
-
+        block_priority_changed_handlers(procdata, TRUE);
         gtk_radio_action_set_current_value(normal, value);
+        block_priority_changed_handlers(procdata, FALSE);
+
     }
     update_sensitivity(procdata);
 }
