@@ -702,7 +702,9 @@ LoadGraph::LoadGraph(guint type)
         case LOAD_GRAPH_MEM:
             n = 2;
             labels.memory = gtk_label_new(NULL);
+            gtk_misc_set_alignment (GTK_MISC (labels.memory), 0.0, 0.5);
             labels.swap = gtk_label_new(NULL);
+            gtk_misc_set_alignment (GTK_MISC (labels.swap), 0.0, 0.5);
             break;
 
         case LOAD_GRAPH_NET:
@@ -710,9 +712,17 @@ LoadGraph::LoadGraph(guint type)
             n = 2;
             net.max = 1;
             labels.net_in = gtk_label_new(NULL);
+            gtk_label_set_width_chars(GTK_LABEL(labels.net_in), 15);
+            gtk_misc_set_alignment (GTK_MISC (labels.net_in), 1.0, 0.5);
             labels.net_in_total = gtk_label_new(NULL);
+            gtk_misc_set_alignment (GTK_MISC (labels.net_in_total), 1.0, 0.5);
+            gtk_label_set_width_chars(GTK_LABEL(labels.net_in_total), 15);
             labels.net_out = gtk_label_new(NULL);
+            gtk_misc_set_alignment (GTK_MISC (labels.net_out), 1.0, 0.5);
+            gtk_label_set_width_chars(GTK_LABEL(labels.net_out), 15);
             labels.net_out_total = gtk_label_new(NULL);
+            gtk_misc_set_alignment (GTK_MISC (labels.net_out_total), 1.0, 0.5);
+            gtk_label_set_width_chars(GTK_LABEL(labels.net_out_total), 15);
             break;
     }
 
@@ -743,7 +753,7 @@ LoadGraph::LoadGraph(guint type)
     render_counter = (frames_per_unit - 1);
     draw = FALSE;
 
-    main_widget = gtk_vbox_new (FALSE, FALSE);
+    main_widget = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_widget_set_size_request(main_widget, -1, LoadGraph::GRAPH_MIN_HEIGHT);
     gtk_widget_show (main_widget);
 
